renamed MASTER into MWFACT, master into mwfact, and incmaster into addtomwfact
authorAnselm R. Garbe <garbeam@gmail.com>
Sun, 12 Aug 2007 12:46:08 +0200
changeset 943 d0b93818f723
parent 942 f8295dc3d5e4
child 944 bd5cf635c601
renamed MASTER into MWFACT, master into mwfact, and incmaster into addtomwfact
config.arg.h
config.default.h
config.mk
tile.c
tile.h
--- a/config.arg.h	Sat Aug 11 14:44:11 2007 +0200
+++ b/config.arg.h	Sun Aug 12 12:46:08 2007 +0200
@@ -32,7 +32,7 @@
 	{ "[]=",		tile }, /* first entry is default */ \
 	{ "><>",		floating }, \
 };
-#define MASTER			0.6	/* 0.1 .. 0.9 */
+#define MWFACT			0.6	/* master width factor [0.1 .. 0.9] */
 #define SNAP			32	/* snap pixel */
 
 /* key definitions */
@@ -49,8 +49,8 @@
 	{ MODKEY,			XK_b,		togglebar,	NULL }, \
 	{ MODKEY,			XK_j,		focusclient,	"1" }, \
 	{ MODKEY,			XK_k,		focusclient,	"-1" }, \
-	{ MODKEY,			XK_h,		incmaster,	"-0.05" }, \
-	{ MODKEY,			XK_l,		incmaster,	"0.05" }, \
+	{ MODKEY,			XK_h,		addtomwfact,	"-0.05" }, \
+	{ MODKEY,			XK_l,		addtomwfact,	"0.05" }, \
 	{ MODKEY,			XK_m,		togglemax,	NULL }, \
 	{ MODKEY,			XK_Return,	zoom,		NULL }, \
 	{ MODKEY|ShiftMask,		XK_space,	togglefloating,	NULL }, \
--- a/config.default.h	Sat Aug 11 14:44:11 2007 +0200
+++ b/config.default.h	Sun Aug 12 12:46:08 2007 +0200
@@ -33,7 +33,7 @@
 	{ "[]=",		tile }, /* first entry is default */ \
 	{ "><>",		floating }, \
 };
-#define MASTER			0.6	/* 0.1 .. 0.9 */
+#define MWFACT			0.6	/* master width factor [0.1 .. 0.9] */
 #define SNAP			32	/* snap pixel */
 
 /* key definitions */
@@ -47,8 +47,8 @@
 	{ MODKEY,			XK_b,		togglebar,	NULL }, \
 	{ MODKEY,			XK_j,		focusclient,	"1" }, \
 	{ MODKEY,			XK_k,		focusclient,	"-1" }, \
-	{ MODKEY,			XK_h,		incmaster,	"-0.05" }, \
-	{ MODKEY,			XK_l,		incmaster,	"0.05" }, \
+	{ MODKEY,			XK_h,		addtomwfact,	"-0.05" }, \
+	{ MODKEY,			XK_l,		addtomwfact,	"0.05" }, \
 	{ MODKEY,			XK_m,		togglemax,	NULL }, \
 	{ MODKEY,			XK_Return,	zoom,		NULL }, \
 	{ MODKEY|ShiftMask,		XK_space,	togglefloating,	NULL }, \
--- a/config.mk	Sat Aug 11 14:44:11 2007 +0200
+++ b/config.mk	Sun Aug 12 12:46:08 2007 +0200
@@ -20,8 +20,8 @@
 # flags
 CFLAGS = -Os ${INCS} -DVERSION=\"${VERSION}\"
 LDFLAGS = -s ${LIBS}
-#CFLAGS = -g -Wall -O2 ${INCS} -DVERSION=\"${VERSION}\"
-#LDFLAGS = -g ${LIBS}
+CFLAGS = -g -Wall -O2 ${INCS} -DVERSION=\"${VERSION}\"
+LDFLAGS = -g ${LIBS}
 
 # Solaris
 #CFLAGS = -fast ${INCS} -DVERSION=\"${VERSION}\"
--- a/tile.h	Sat Aug 11 14:44:11 2007 +0200
+++ b/tile.h	Sun Aug 12 12:46:08 2007 +0200
@@ -1,6 +1,6 @@
 /* See LICENSE file for copyright and license details. */
 
 /* tile.c */
-void incmaster(const char *arg);	/* inc/decreases the master width */
+void addtomwfact(const char *arg);	/* adds arg value [0.1 .. 0.9] to master width factor */
 void tile(void);			/* arranges all windows tiled */
 void zoom(const char *arg);		/* zooms the focused client to master area, arg is ignored */
--- a/tile.c	Sat Aug 11 14:44:11 2007 +0200
+++ b/tile.c	Sun Aug 12 12:46:08 2007 +0200
@@ -4,23 +4,22 @@
 
 /* static */
 
-static double master = MASTER;
+static double mwfact = MWFACT;
 
 /* extern */
 
 void
-incmaster(const char *arg) {
+addtomwfact(const char *arg) {
 	double delta;
 
 	if(lt->arrange != tile)
 		return;
 
 	/* arg handling, manipulate master */
 	if(arg && (1 == sscanf(arg, "%lf", &delta))) {
-		if(delta + master > 0.1 && delta + master < 0.9)
-			master += delta;
+		if(delta + mwfact > 0.1 && delta + mwfact < 0.9)
+			mwfact += delta;
 	}
-
 	lt->arrange();
 }
 
@@ -33,7 +32,7 @@
 		n++;
 
 	/* window geoms */
-	mw = (n == 1) ? waw : master * waw;
+	mw = (n == 1) ? waw : mwfact * waw;
 	th = (n > 1) ? wah / (n - 1) : 0;
 	if(n > 1 && th < bh)
 		th = wah;
@@ -4,23 +4,22 @@
 		return;
 
-	/* arg handling, manipulate master */
+	/* arg handling, manipulate mwfact */
 	if(arg && (1 == sscanf(arg, "%lf", &delta))) {